# Optimization examples

## Single objective two parameters
This example optimizes groundwater parameters `K_aquitard` and `Z_aquitard`
There are three version using different optimizers.

* [Single objective with two parameters using sequential](single_objective_two_parameters_sequential.py)
* [Single objective with two parameters using CMA](single_objective_two_parameters_cma.py)
* [Single objective with two parameters using Ax](single_objective_two_parameters_ax.py)

## Single objective with one Daisy and one Python parameter

* [Single objective with python](single_objective_with_python.py)


## Multiple scenarios
There are two versions, one with a single Daisy parameter and one with a single Daisy and a single Python parameter
* [Multiple scenarios](multiple_scenarios.py)
* [Multiple scenarios with python](multiple_scenarios_with_python.py)


## Multiple objectives
Optimization of three objectives and a single Daisy parameter
* [Multi objective using Ax](multi_objective_ax.py)


## Combining outputs from multiple log files
Optimization of a combination of three outputs from two log files. Two fertilizer weight parameters. Using CMA.
* [Single objective combined outputs](single_objective_combined_outputs.py])
